==> apache-cxf-3.5.10-src.zip: apache-cxf-3.5.10-src/rt/frontend/jaxws/src/main/java/org/apache/cxf/jaxws/handler/types/PathType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxws.handler.types;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;

/**
 * The elements that use this type designate either a relative path or an absolute path starting with a "/".
 * In elements that specify a pathname to a file within the same Deployment File, relative filenames (i.e.,
 * those not starting with "/") are considered relative to the root of the Deployment File's namespace.
 * Absolute filenames (i.e., those starting with "/") also specify names in the root of the Deployment File's
 * namespace. In general, relative names are preferred. The exception is .war files where absolute names are
 * preferred for consistency with the Servlet API.
 * <p>
 * Java class for pathType complex type.
 * <p>
 * The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="pathType">
 *   &lt;simpleContent>
 *     &lt;restriction base="&lt;http://java.sun.com/xml/ns/javaee>string">
 *     &lt;/restriction>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "pathType")
public class PathType extends CString {

}

==> apache-cxf-4.0.9-src.zip: apache-cxf-4.0.9-src/rt/frontend/jaxws/src/main/java/org/apache/cxf/jaxws/handler/types/PathType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxws.handler.types;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;

/**
 * The elements that use this type designate either a relative path or an absolute path starting with a "/".
 * In elements that specify a pathname to a file within the same Deployment File, relative filenames (i.e.,
 * those not starting with "/") are considered relative to the root of the Deployment File's namespace.
 * Absolute filenames (i.e., those starting with "/") also specify names in the root of the Deployment File's
 * namespace. In general, relative names are preferred. The exception is .war files where absolute names are
 * preferred for consistency with the Servlet API.
 * <p>
 * Java class for pathType complex type.
 * <p>
 * The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="pathType">
 *   &lt;simpleContent>
 *     &lt;restriction base="&lt;http://java.sun.com/xml/ns/javaee>string">
 *     &lt;/restriction>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "pathType")
public class PathType extends CString {

}
